@@ -25,7 +25,7 @@ from sym.cli.saml_clients.saml_client import SAMLClient
 from ..ansible import connection
 from ..helpers import os
 from ..helpers.contexts import push_envs
-from ..helpers.params import get_ssh_user
+from ..helpers.params import get_ansible_user, get_ssh_user
 from ..helpers.ssh import ssh_key_and_config
 from ..helpers.tee import Tee
 from ..saml_clients.aws_profile import AwsCredentialsPath, AwsProfile
@@ -66,13 +66,17 @@ def ansible_connection_plugins_value() -> str:
     )
 
 
+def ansible_profile_proxy(client):
+    return client.clone(klass=AwsProfile, resource=ANSIBLE_SSH_PROFILE)
+
+
 def sym_subcommand(client, subcommand, args="") -> str:
-    proxy_client = client.clone(klass=AwsProfile, resource=ANSIBLE_SSH_PROFILE)
+    proxy_client = ansible_profile_proxy(client)
     return f"sym {proxy_client.cli_options} {subcommand} {proxy_client.resource} {args}"
 
 
 def create_ssh_bin(client):
-    proxy_client = client.clone(klass=AwsProfile, resource=ANSIBLE_SSH_PROFILE)
+    proxy_client = ansible_profile_proxy(client)
     ssh_bin = proxy_client.subconfig(ANSIBLE_SSH_PATH)
 
     command = sym_subcommand(client, "ssh", '"$@"')
@@ -123,6 +127,7 @@ def get_send_command_args(client: SAMLClient):
         "ansible_aws_ssm_bucket": bucket_name,
         "ansible_aws_ssm_host_cmd": sym_host_to_instance_cmd,
         "ansible_aws_ssm_region": BUCKET_REGION,
+        "ansible_aws_ssm_profile": ANSIBLE_SSH_PROFILE,
     }
     return " ".join(f"{k}='{v}'" for k, v in extra_vars.items())
 
@@ -144,11 +149,13 @@ def run_ansible(
     ssh_key, _ = ssh_key_and_config(client)
     args = [
         binary,
-        *command,
         f"--user={get_ssh_user()}",
+        f"--become" if get_ansible_user() != get_ssh_user() else None,
+        f"--become-user={get_ansible_user()}",
         f"--private-key={ssh_key}",
         f"--scp-extra-args=-S '{ssh_bin}'",
         f"--sftp-extra-args=-S '{ssh_bin}'",
+        *command,
     ]
 
     envs = get_ansible_env(ssh_bin, debug=client.debug, control_master=control_master)
