@@ -3,6 +3,10 @@ from typing import Callable, Union
 import click
 from click_option_group import MutuallyExclusiveOptionGroup
 
+from sym.cli.constants.env import SYM_USE_CONTROL_MASTER
+from sym.cli.helpers.ssh import check_ssh_version
+from sym.cli.helpers.util import flow
+
 from ..saml_clients.chooser import choose_saml_client
 from .config import Config
 from .envvar_option import EnvvarGroupedOption, EnvvarOption
@@ -64,22 +68,45 @@ def resource_argument(f):
     return option_decorator(f)
 
 
-def aws_profile_options(f):
+def ansible_options(f):
     group = MutuallyExclusiveOptionGroup("Ansible Roles")
-    ansible_aws_profile = group.option(
-        "--ansible-aws-profile",
-        help="the local AWS Profile to use for Ansible commands",
-        envvar="AWS_PROFILE",
-        cls=EnvvarGroupedOption,
-    )
-    ansible_sym_resource = group.option(
-        "--ansible-sym-resource",
-        help="the Sym resource to use for Ansible commands",
-        envvar="SYM_ANSIBLE_RESOURCE",
-        callback=_resource_arg_callback,
-        cls=EnvvarGroupedOption,
-    )
-    return ansible_aws_profile(ansible_sym_resource(f))
+    options = [
+        group.option(
+            "--ansible-aws-profile",
+            help="the local AWS Profile to use for Ansible commands",
+            envvar="AWS_PROFILE",
+            cls=EnvvarGroupedOption,
+        ),
+        group.option(
+            "--ansible-sym-resource",
+            help="the Sym resource to use for Ansible commands",
+            envvar="SYM_ANSIBLE_RESOURCE",
+            callback=_resource_arg_callback,
+            cls=EnvvarGroupedOption,
+        ),
+        click.option(
+            "--control-master/--no-control-master",
+            help="allow SSH ControlPath caching",
+            envvar=SYM_USE_CONTROL_MASTER,
+            is_flag=True,
+            default=check_ssh_version,
+            cls=EnvvarOption,
+        ),
+        click.option(
+            "--send-command/--no-send-command",
+            help="Use SSM SendCommand instead of SSH",
+            envvar="SYM_SEND_COMMAND",
+            is_flag=True,
+            default=True,
+            cls=EnvvarOption,
+        ),
+        click.option(
+            "--forks",
+            help="number of parallel subprocesses for ansible",
+            default=15,
+        ),
+    ]
+    return flow(options, f)
 
 
 def required_option(*args, if_, **kwargs):
