@@ -1,4 +1,3 @@
-import os
 from typing import Dict, NamedTuple, Optional, TypedDict
 
 import validators
@@ -12,11 +11,12 @@ class Profile(NamedTuple):
     region: str
     arn: str
     aws_saml_url: Optional[str] = None
+    ansible_bucket: Optional[str] = None
 
 
 class OrgParams(TypedDict, total=False):
     resource_env_var: Optional[str]
-    ssh_user: str
+    users: Dict[str, str]
     domain: str
     aws_saml_url: str
     aws_okta_params: Dict[str, str]
@@ -27,7 +27,7 @@ class OrgParams(TypedDict, total=False):
 PARAMS: Dict[str, OrgParams] = {
     "launch-darkly": {
         "resource_env_var": "ENVIRONMENT",
-        "ssh_user": "ubuntu",
+        "users": {"ssh": "ubuntu", "ansible": "ansible"},
         "domain": "launchdarkly.com",
         "aws_saml_url": (
             "https://launchdarkly.okta.com/home/amazon_aws/0oaj4aow7gPk26Fy6356/272"
@@ -44,32 +44,37 @@ PARAMS: Dict[str, OrgParams] = {
                 display_name="Prod",
                 region="us-east-1",
                 arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-production",
+                ansible_bucket="launchdarkly-sym-ansible-prod",
             ),
             "staging": Profile(
                 display_name="Staging",
                 region="us-east-1",
                 arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-staging",
+                ansible_bucket="launchdarkly-sym-ansible-staging",
             ),
             "catfood": Profile(
                 display_name="Catfood",
                 region="us-east-1",
                 arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-catamorphic",
+                ansible_bucket="launchdarkly-sym-ansible-catfood",
             ),
             "prod-intuit": Profile(
                 display_name="Prod: Intuit",
                 region="us-west-2",
                 arn="arn:aws:iam::527291094460:role/ops/SSHAdmin-production",
+                ansible_bucket="launchdarkly-sym-ansible-prod-intuit",
             ),
             "staging-intuit": Profile(
                 display_name="Staging: Intuit",
                 region="us-west-2",
                 arn="arn:aws:iam::527291094460:role/ops/SSHAdmin-staging",
+                ansible_bucket="launchdarkly-sym-ansible-staging-intuit",
             ),
         },
     },
     "sym": {
         "resource_env_var": "ENVIRONMENT",
-        "ssh_user": "ubuntu",
+        "users": {"ssh": "ubuntu", "ansible": "ubuntu"},
         "domain": "symops.io",
         "aws_saml_url": (
             "https://dev-291131.okta.com/home/amazon_aws/0oaqlmsn7GMVgAyBK4x6/272"
@@ -119,7 +124,11 @@ def get_domain() -> str:
 
 
 def get_ssh_user() -> str:
-    return get_org_params()["ssh_user"]
+    return get_org_params()["users"]["ssh"]
+
+
+def get_ansible_user() -> str:
+    return get_org_params()["users"]["ansible"]
 
 
 def get_resource_env_vars() -> Optional[str]:
