@@ -258,7 +258,7 @@ def test_ansible_playbook_send_command(
             "--connection=sym_aws_ssm",
             "--forks=15",
             f"--user={get_ssh_user()}",
-            f"--extra-vars=ansible_aws_ssm_bucket='sym-ansible-{TEST_ACCOUNT}' ansible_aws_ssm_host_cmd='sym --saml-client aws-profile --log-dir {os.environ['SYM_LOG_DIR']} host-to-instance sym-ansible $HOST' ansible_aws_ssm_region='us-east-1'",
+            f"--extra-vars=ansible_aws_ssm_bucket='sym-ansible-{TEST_ACCOUNT}' ansible_aws_ssm_host_cmd='sym --saml-client aws-profile --log-dir {os.environ['SYM_LOG_DIR']} host-to-instance sym-ansible $HOST' ansible_aws_ssm_region='us-east-1' ansible_aws_ssm_profile='sym-ansible'",
         ]
         capture_command.assert_commands(
             [
@@ -294,7 +294,7 @@ def test_ansible_playbook_send_command_low_forks(
             "--connection=sym_aws_ssm",
             "--forks=5",
             f"--user={get_ssh_user()}",
-            f"--extra-vars=ansible_aws_ssm_bucket='sym-ansible-{TEST_ACCOUNT}' ansible_aws_ssm_host_cmd='sym --saml-client aws-profile --log-dir {os.environ['SYM_LOG_DIR']} host-to-instance sym-ansible $HOST' ansible_aws_ssm_region='us-east-1'",
+            f"--extra-vars=ansible_aws_ssm_bucket='sym-ansible-{TEST_ACCOUNT}' ansible_aws_ssm_host_cmd='sym --saml-client aws-profile --log-dir {os.environ['SYM_LOG_DIR']} host-to-instance sym-ansible $HOST' ansible_aws_ssm_region='us-east-1' ansible_aws_ssm_profile='sym-ansible'",
         ]
         capture_command.assert_commands(
             [
